%define upstream_name    Dist-CheckConflicts
%define upstream_version 0.11

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 9

Summary:    Declare version conflicts for your dist
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Dist/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Carp)
BuildRequires: perl(Exporter)
BuildRequires: perl(ExtUtils::MakeMaker) >= 6.300.0
BuildRequires: perl(File::Find)
BuildRequires: perl(File::Temp)
BuildRequires: perl(List::MoreUtils) >= 0.120.0
BuildRequires: perl(Module::Runtime)
BuildRequires: perl(Test::Fatal)
BuildRequires: perl(Test::More) >= 0.880.0
BuildRequires: perl(Test::Warnings)
BuildRequires: perl(base)
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildArch:  noarch

%description
One shortcoming of the CPAN clients that currently exist is that they have
no way of specifying conflicting downstream dependencies of modules. This
module attempts to work around this issue by allowing you to specify
conflicting versions of modules separately, and deal with them after the
module is done installing.

For instance, say you have a module 'Foo', and some other module 'Bar' uses
'Foo'. If 'Foo' were to change its API in a non-backwards-compatible way,
this would cause 'Bar' to break until it is updated to use the new API.
'Foo' can't just depend on the fixed version of 'Bar', because this will
cause a circular dependency (because 'Bar' is already depending on 'Foo'),
and this doesn't express intent properly anyway - 'Foo' doesn't use 'Bar'
at all. The ideal solution would be for there to be a way to specify
conflicting versions of modules in a way that would let CPAN clients update
conflicting modules automatically after an existing module is upgraded, but
until that happens, this module will allow users to do this manually.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test

%install
%make_install

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README
%{_mandir}/man3/*
%perl_vendorlib/*


%changelog
* Thu Jun 26 2025 umeabot <umeabot> 0.110.0-9.mga10
+ Revision: 2198262
- Mageia 10 Mass Rebuild

* Sun Mar 20 2022 umeabot <umeabot> 0.110.0-8.mga9
+ Revision: 1803022
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 0.110.0-7.mga8
+ Revision: 1494053
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Wed Sep 19 2018 umeabot <umeabot> 0.110.0-6.mga7
+ Revision: 1267284
- Mageia 7 Mass Rebuild

* Sun Jun 19 2016 pterjan <pterjan> 0.110.0-5.mga6
+ Revision: 1025805
- Rebuild for perl 5.22.2

* Mon Feb 08 2016 umeabot <umeabot> 0.110.0-4.mga6
+ Revision: 945716
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.110.0-3.mga5
+ Revision: 741331
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.110.0-2.mga5
+ Revision: 684379
- Mageia 5 Mass Rebuild

* Sat May 17 2014 sander85 <sander85> 0.110.0-1.mga5
+ Revision: 623234
- update to 0.11

* Sat Feb 08 2014 sander85 <sander85> 0.100.0-1.mga5
+ Revision: 586534
- update to 0.10

* Sat Oct 19 2013 umeabot <umeabot> 0.90.0-2.mga4
+ Revision: 530290
- Mageia 4 Mass Rebuild

* Mon Jul 22 2013 sander85 <sander85> 0.90.0-1.mga4
+ Revision: 457044
- update to 0.09

* Sun Jul 14 2013 sander85 <sander85> 0.80.0-1.mga4
+ Revision: 454160
- update to 0.08

* Tue Jul 09 2013 sander85 <sander85> 0.70.0-1.mga4
+ Revision: 452034
- update to 0.07

* Wed Jun 26 2013 jquelin <jquelin> 0.60.0-1.mga4
+ Revision: 446902
- update to 0.06

* Sun Jan 13 2013 umeabot <umeabot> 0.20.0-2.mga3
+ Revision: 365999
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 19 2011 jquelin <jquelin> 0.20.0-1.mga1
+ Revision: 24501
- fix specs
- imported package perl-Dist-CheckConflicts


* Fri Jan 07 2011 Guillaume Rousse <guillomovitch@mandriva.org> 0.20.0-1mdv2011.0
+ Revision: 629544
- import perl-Dist-CheckConflicts

